Stellar v0.3.1 Stellar.XDR.Types.Transaction.OperationType View Source
Link to this section Summary
Functions
Decodes an XDR binary to a native type, also returns any un-decoded binary
Encodes a native type to an XDR binary
Returns the expected length (in bytes) of an XDR-encoded binary of this type (sans padding)
Returns the input if it's a valid XDR module native type, or the default valid native type
Determines if a value is a valid XDR type
Link to this section Functions
decode(name) View Source
Decodes an XDR binary to a native type, also returns any un-decoded binary
Callback implementation for XDR.Type.Base.decode/1.
encode(name) View Source
Encodes a native type to an XDR binary
Callback implementation for XDR.Type.Base.encode/1.
length() View Source
Returns the expected length (in bytes) of an XDR-encoded binary of this type (sans padding)
Callback implementation for XDR.Type.Base.length/0.
new(name) View Source
Returns the input if it's a valid XDR module native type, or the default valid native type
Callback implementation for XDR.Type.Base.new/1.
valid?(name) View Source
Determines if a value is a valid XDR type
Callback implementation for XDR.Type.Base.valid?/1.